split_prefix

Function split_prefix 

fn split_prefix<'a, 'b>(
    left: &'a str,
    right: &'b str,
) -> (&'a str, &'a str, &'b str)
Finds the identical prefix of left and right containing guaranteed well-format UTF-8.

Returns the identical prefix, the part of left after the prefix, and the part of right after the prefix.