split_prefix_u8

Function split_prefix_u8 

fn split_prefix_u8<'a, 'b>(
    left: &'a [u8],
    right: &'b [u8],
) -> (&'a [u8], &'a [u8], &'b [u8])
Finds the identical prefix of left and right containing potentially ill-formed UTF-8, while avoiding splitting a UTF-8 byte sequence. In case of ill-formed UTF-8, the prefix is not guaranteed to be maximal.

Returns the identical prefix, the part of left after the prefix, and the part of right after the prefix.