Collator

Struct Collator 

pub struct Collator {
    special_primaries: DataPayload<ErasedMarker<CollationSpecialPrimariesValidated<'static>>>,
    root: DataPayload<CollationRootV1>,
    tailoring: Option<DataPayload<CollationTailoringV1>>,
    jamo: DataPayload<CollationJamoV1>,
    diacritics: DataPayload<CollationDiacriticsV1>,
    options: CollatorOptionsBitField,
    reordering: Option<DataPayload<CollationReorderingV1>>,
    decompositions: DataPayload<NormalizerNfdDataV1>,
    tables: DataPayload<NormalizerNfdTablesV1>,
    lithuanian_dot_above: bool,
}
Compares strings according to culturally-relevant ordering.

Fields

special_primaries: DataPayload<ErasedMarker<CollationSpecialPrimariesValidated<'static>>>root: DataPayload<CollationRootV1>tailoring: Option<DataPayload<CollationTailoringV1>>jamo: DataPayload<CollationJamoV1>diacritics: DataPayload<CollationDiacriticsV1>options: CollatorOptionsBitFieldreordering: Option<DataPayload<CollationReorderingV1>>decompositions: DataPayload<NormalizerNfdDataV1>tables: DataPayload<NormalizerNfdTablesV1>lithuanian_dot_above: bool

Implementations

Source

impl Collator

pub fn as_borrowed(&self) -> CollatorBorrowed<'_>

Constructs a borrowed version of this type for more efficient querying.

pub fn try_new( prefs: CollatorPreferences, options: CollatorOptions, ) -> Result<CollatorBorrowed<'static>, DataError>

Creates CollatorBorrowed for the given locale and options from compiled data.

pub fn try_new_unstable<D>( provider: &D, prefs: CollatorPreferences, options: CollatorOptions, ) -> Result<Self, DataError>

A version of Self::try_new that uses custom data provided by a DataProvider.

📚 Help choosing a constructor

⚠️ The bounds on provider may change over time, including in SemVer minor releases.
fn try_new_unstable_internal<D>( provider: &D, root: DataPayload<CollationRootV1>, decompositions: DataPayload<NormalizerNfdDataV1>, tables: DataPayload<NormalizerNfdTablesV1>, jamo: DataPayload<CollationJamoV1>, special_primaries: DataPayload<CollationSpecialPrimariesV1>, prefs: CollatorPreferences, options: CollatorOptions, ) -> Result<Self, DataError>