fn split_prefix_latin1<'a, 'b>(
left: &'a [u8],
right: &'b [u8],
) -> (&'a [u8], &'a [u8], &'b [u8])Expand description
Finds the identical prefix of left and right containing
Latin1.
Returns the identical prefix, the part of left after the
prefix, and the part of right after the prefix.
✨ Enabled with the latin1 Cargo feature.