fn split_prefix_latin1_utf16<'a, 'b>(
left: &'a [u8],
right: &'b [u16],
) -> (&'a [u8], &'a [u8], &'b [u16])Expand description
Finds the identical prefix of left containing Latin1
and right containing potentially ill-formed UTF-16.
Returns the identical prefix, the part of left after the
prefix, and the part of right after the prefix.
✨ Enabled with the latin1 Cargo feature.